module Workarea
  module Storefront
    class RegistriesController < ApplicationController
      before_action :find_registry, only: :show
      before_action :check_permissions, only: :show

      def index
        @page = Storefront::ContentViewModel.new(
          Content.for('registries'),
          view_model_options
        )
      end

      def show
      end

      def search
        if params[:registry_query].present?
          @registries = Registry
                        .search(params[:registry_query])
                        .page(params[:page] || 1)
        end
      end

      private

      def find_registry
        @registry = RegistryViewModel.wrap(
          Registry.find_by(id: params[:id]),
          { :state => 'available' }
        )
      end

      def check_permissions
        if @registry.private? && registry_guest?
          flash[:error] = t('workarea.storefront.flash_messages.private_registry')
          redirect_to registries_path
        end
      end

      def registry_guest?
        return true unless current_user
        current_user.id.to_s != @registry.user_id
      end
    end
  end
end
