module Workarea
  module Storefront
    class Users::RegistriesController < ApplicationController
      before_action :require_login
      before_action :find_registry, except: [:index, :new, :create]

      def index
        @registries = Storefront::RegistryViewModel.wrap(
          Registry.for_user(current_user.id).by_activity,
          view_model_options
        )
      end

      def new
        @registry = RegistryViewModel.wrap(
          Workarea::Registry.new,
          view_model_options
        )
      end

      def create
        @registry = RegistryViewModel.wrap(
          Workarea::Registry.new(registry_params.merge(address: registry_address_params)),
          view_model_options
        )

        if @registry.save
          flash[:success] = t('workarea.storefront.flash_messages.registry_created')
          redirect_to users_registry_path(@registry)
        else
          flash[:error] = t('workarea.storefront.flash_messages.registry_not_created')
          redirect_to users_account_path
        end
      end

      def show; end

      def edit; end

      def update
        if @registry.update(registry_params.merge(address: registry_address_params))
          flash[:success] = t('workarea.storefront.flash_messages.registry_updated')
        else
          flash[:error] = t('workarea.storefront.flash_messages.registry_not_updated')
        end

        redirect_to users_registry_path(@registry)
      end

      def destroy
        @registry.destroy

        flash[:success] =
          t('workarea.storefront.flash_messages.registry_destroyed')
        redirect_to users_account_path
      end

      private

      def registry_params
        params[:registry].permit(
          :user_id,
          :email,
          :name,
          :description,
          :privacy,
          :event_date
        )
      end

      def registry_address_params
        params[:registry_address].permit(
          :first_name,
          :last_name,
          :company,
          :street,
          :street_2,
          :city,
          :country,
          :region,
          :postal_code,
          :phone_number
        )
      end

      def find_registry
        @registry = RegistryViewModel.wrap(
          Registry.find_by(id: params[:id], user_id: current_user.id),
          view_model_options
        )
      end
    end
  end
end
