module Workarea
  module Storefront
    class Users::RegistryItemsController < ApplicationController
      before_action :require_login
      before_action :find_registry, except: [:new]
      before_action :find_item, except: [:new, :create, :update]

      def new
        @registries = RegistryViewModel.wrap(
          Registry.for_user(current_user.id),
          view_model_options
        )

        @product = ProductViewModel.wrap(
          Catalog::Product.find(params[:product_id]),
          view_model_options
        )
      end

      def create
        if @registry.add_item(item_params)
          flash[:success] = t('workarea.storefront.flash_messages.registry_item_created')
        else
          flash[:error] = t('workarea.storefront.flash_messages.registry_item_not_created')
        end

        redirect_to users_registry_path(@registry)
      end

      def update
        if @registry.update_item(params[:id], item_params)
          flash[:success] = t('workarea.storefront.flash_messages.registry_item_updated')
        else
          flash[:error] = t('workarea.storefront.flash_messages.registry_item_not_updated')
        end

        redirect_to users_registry_path(@registry)
      end

      def destroy
        if @item.unpurchased?
         @registry.remove_item(params[:id])
          flash[:success] = t('workarea.storefront.flash_messages.registry_item_destroyed')
        else
          flash[:error] = t('workarea.storefront.flash_messages.registry_item_not_destroyed')
        end

        redirect_to users_registry_path(@registry)
      end

      private

      def item_params
        params.permit(:product_id, :sku, :quantity, :purchased_by)
      end

      def find_registry
        @registry =
          Registry.for_user(current_user.id).find(params[:registry_id])
      end

      def find_item
        @item = @registry.items.find(params[:id])
      end
    end
  end
end
