module Workarea
  class Registry
    class Item
      include ApplicationDocument

      field :product_id, type: String
      field :sku, type: String
      field :quantity, type: Integer, default: 1
      field :received, type: Integer, default: 0
      field :purchased_by, type: String
      field :total_price, type: Money, default: 0.to_m

      embedded_in :registry,
        class_name: 'Workarea::Registry',
        touch: true

      validates :product_id, presence: true
      validates :sku, presence: true
      validates :quantity, presence: true, numericality: { greater_than: 0 }

      index(product_id: 1)

      def available?
        quantity > received
      end

      def unavailable?
        !available?
      end

      def received?
        received.positive?
      end

      def purchased?
        purchased_by.present?
      end

      def unpurchased?
        !purchased? && !received?
      end
    end
  end
end
