module Workarea
  class ActiveRegistriesReport
    include ActionView::Helpers::NumberHelper
    attr_reader :file_path

    def initialize
      @file_path = "#{Rails.root}/tmp/active_registries/report.csv"
    end

    def generate
      dir_path = File.dirname(file_path)
      FileUtils.mkdir_p dir_path unless File.directory?(dir_path)
      CSV.open(file_path, 'w') do |csv|
        csv << [
          'Name',
          'Email',
          'Products',
          'Items',
          'Purchased Items',
          'Total Price',
        ]
        populate_csv(csv)
      end
    end

    private

    def populate_csv(csv)
      Registry.with_items.order_by(created_at: :desc).each_by(100) do |registry|
        registry = Admin::ActiveRegistryViewModel.new(registry)

        csv << [
          registry.name,
          registry.email,
          registry.total_products,
          registry.total_items,
          registry.total_purchased_items,
          number_to_currency(registry.total_price)
        ]
      end
    end
  end
end
