module Workarea
  module Storefront
    class RegistryItemViewModel < CartItemViewModel
      delegate :on_sale?, to: :price
      delegate :has_prices?, :primary_image, :purchasable?, to: :product

      def product
        @product ||= ProductViewModel.wrap(
          catalog_product,
          options.merge(sku: sku)
        )
      end

      def catalog_product
        @catalog_product ||= Catalog::Product.find(product_id)
      end

      def template
        if purchased_by?
          I18n.t('workarea.storefront.registry.item.purchased')
        else
          I18n.t('workarea.storefront.registry.item.unpurchased')
        end
      end

      # maintain compatibility with OrderItemViewModel
      def customized?
        false
      end

      def original_price
        price.regular
      end

      def original_unit_price
        price.sell
      end

      def total_price
        original_unit_price * quantity
      end

      def price
        @pricing ||=
          options[:pricing]&.for_sku(sku, quantity: quantity) ||
          Pricing::Sku.find_or_create_by(id: sku).find_price(quantity: quantity)
      end

      def inventory
        @inventory ||=
          options[:inventory]&.for_sku(sku) ||
          Inventory::Sku.find_or_create_by(id: sku)
      end

      def inventory_status
        InventoryStatusViewModel.new(inventory).message
      end

      def insufficient_inventory?
        inventory.available_to_sell < quantity
      end

      def received?
        received.positive?
      end

      def available_quantity
        quantity - received
      end
    end
  end
end
