module Workarea
  module Storefront
    class RegistryViewModel < ApplicationViewModel
      def user
        @user ||=
          options[:user] ||
          UserViewModel.wrap(User.find(user_id))
      end

      def address
        model.address ||
        user.try(:default_shipping_address) ||
        Address.new
      end

      def email
        model.email || user.try(:email)
      end

      def owner
        user.name.present? ? user.name : user.email
      end

      def items
        @items ||=
          begin
            items = if options[:state] == 'purchased'
              model.purchased_items
            elsif options[:state] == 'available'
              model.available_items
            else
              model.unpurchased_items
            end

            items.map do |item|
              RegistryItemViewModel.wrap(
                item,
                options.merge(inventory: inventory, pricing: pricing)
              )
            end
          end
      end

      def state_options
        [
          [I18n.t('workarea.storefront.registries.unpurchased_items'), :unpurchased],
          [I18n.t('workarea.storefront.registries.purchased_items'), :purchased]
        ]
      end

      def event_date
        model.event_date.try(:to_date)
      end

      def registry_label
        I18n.t('workarea.storefront.registries.registry_label', name: model.name)
      end

      private

      def inventory
        @inventory ||= Inventory::Collection.new(skus)
      end

      def pricing
        @pricing ||= Pricing::Collection.new(skus)
      end

      def skus
        model.items.map(&:sku)
      end
    end
  end
end
